package cn.com.infosec.mobile.android;

import android.content.Context;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.util.Base64;
import cn.com.infosec.mobile.android.cert.InfosecCert;
import cn.com.infosec.mobile.android.otp.InfosecOTP;
import cn.com.infosec.mobile.android.result.Result;
import cn.com.infosec.mobile.android.sign.InfosecSign;
import cn.com.infosec.mobile.android.util.Util;
import cn.com.infosec.mobile.android.xlog.XLog;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.json.JSONException;
import org.json.JSONObject;

public class IMSSignAction extends IMSAction {
   private InfosecSign infosecSign;
   private InfosecCert infosecCert;

   public IMSSignAction(Context context) {
      IMSSignAction var10000 = this;
      IMSSignAction var10001 = this;
      super(context);
      InfosecSign var2;
      var2 = new InfosecSign.<init>();
      var10001.infosecSign = var2;
      InfosecCert var3;
      var3 = new InfosecCert.<init>();
      var10000.infosecCert = var3;
   }

   public Map<String, String> collaborateSignBegin(@NonNull String userName, byte[] plain, boolean isHashSign, @NonNull Jointer jointer) {
      String var9;
      if (!TextUtils.isEmpty(userName) && plain != null) {
         long var5 = 0L;
         if (this.isInfosecCollaborative()) {
            var5 = jointer.createHomoKeyNative(1024);
            if (IMSSdk.enableDebugLog) {
               XLog.d("jointer.createHomoKeyNative " + var5);
            }
         }

         jointer.writeCacheData("HOMO_KEY_LABEL", var5);
         InfosecCert var7;
         var7 = new InfosecCert.<init>();
         if (IMSSdk.enableDebugLog) {
            XLog.d("infosecCert.getPublicKeyWithCertNative " + userName);
         }

         var9 = Base64.encodeToString(var7.getPublicKeyWithCertNative((new IMSCertAction(super.context)).getCertString(userName)), 2);
         if (IMSSdk.enableDebugLog) {
            XLog.d("infosecCert.getPublicKeyWithCertNative, publicKey = " + var9);
         }

         byte[][] var13;
         if (isHashSign) {
            if (plain.length > 0 && IMSSdk.enableDebugLog) {
               XLog.d("jointer.signHashInitNative" + Arrays.toString(new String[]{String.valueOf(var5), Base64.encodeToString(plain, 2)}));
            }

            var13 = jointer.signHashInitNative(var5, plain);
         } else {
            if (plain.length > 0 && IMSSdk.enableDebugLog) {
               XLog.d("jointer.signPlainInitNative" + Arrays.toString(new String[]{String.valueOf(var5), Base64.encodeToString(plain, 2), var9}));
            }

            var13 = jointer.signPlainInitNative(var5, plain, var9);
         }

         byte[] var10 = var13[0];
         plain = var13[1];
         if (IMSSdk.enableDebugLog) {
            if (var10 != null && var10.length > 0) {
               XLog.d("jointer.signPlainInitNative, session = " + Base64.encodeToString(var10, 2));
            }

            if (plain != null && plain.length > 0) {
               XLog.d("jointer.signPlainInitNative, signInitData = " + Base64.encodeToString(plain, 2));
            }
         }

         jointer.writeCacheData("COLLABORATE_SESSION", var10);
         HashMap var15 = new HashMap();
         var15.put("username", userName);
         var15.put("initdata", Base64.encodeToString(plain, 2));
         InfosecOTP var17 = new InfosecOTP();
         String var10004 = userName.concat("_").concat("COLLABORATIVE_OTP_SEED");
         long var11 = System.currentTimeMillis() / 1000L;
         var15.put("num", var17.getOTP(var10004, userName, "GUOMI", var11, (String)null, 6, 60));
         var15.put("imei", Util.getIdentifier(IMSSdk.mContext));
         return var15;
      } else {
         IMSSignAction var10000 = this;
         Logger var10001 = IMSSdk.mLogger;
         Level var10002 = Level.SEVERE;
         String[] var8;
         String[] var10003 = var8 = new String[2];
         var10003[0] = userName;
         String isHashSign1;
         isHashSign1 = new String.<init>(plain);
         var10003[1] = isHashSign1;
         var10001.log(var10002, "协同签名失败:参数不合法", var8);
         StringBuilder var14 = (new StringBuilder()).append("协同签名失败:参数不合法");
         String[] var16 = new String[]{userName, null};
         var9 = new String.<init>(plain);
         var16[1] = var9;
         XLog.d(var14.append(Arrays.toString(var16)).toString());
         var10000.setLatestResult(new Result("IE1013"));
         return null;
      }
   }

   public Result collaborateSignFinal(@NonNull String userName, @NonNull String PIN, byte[] plain, int type, JSONObject responseData, @NonNull Jointer jointer) {
      JSONException var10000;
      label301: {
         boolean var10001;
         Result var61;
         try {
            var61 = this.checkResponseData(responseData);
         } catch (JSONException var53) {
            var10000 = var53;
            var10001 = false;
            break label301;
         }

         Result var7 = var61;
         String var62 = "000000";

         boolean var63;
         try {
            var63 = TextUtils.equals(var62, var7.getResultID());
         } catch (JSONException var52) {
            var10000 = var52;
            var10001 = false;
            break label301;
         }

         if (!var63) {
            return var7;
         }

         Jointer var64;
         long var65;
         try {
            var64 = jointer;
            var65 = (Long)jointer.readCacheData("HOMO_KEY_LABEL");
         } catch (JSONException var51) {
            var10000 = var51;
            var10001 = false;
            break label301;
         }

         long var59 = var65;

         byte[] var67;
         try {
            var67 = (byte[])var64.readCacheData("COLLABORATE_SESSION");
         } catch (JSONException var50) {
            var10000 = var50;
            var10001 = false;
            break label301;
         }

         byte[] var9 = var67;

         String var68;
         try {
            var68 = responseData.getString("data");
         } catch (JSONException var49) {
            var10000 = var49;
            var10001 = false;
            break label301;
         }

         String var10 = var68;
         String[] var10002;
         String[] var10003;
         String[] var10006;
         String[] var71;
         StringBuilder var73;
         if (var67 != null) {
            int var69;
            try {
               var69 = var9.length;
            } catch (JSONException var48) {
               var10000 = var48;
               var10001 = false;
               break label301;
            }

            if (var69 > 0) {
               try {
                  var63 = IMSSdk.enableDebugLog;
               } catch (JSONException var47) {
                  var10000 = var47;
                  var10001 = false;
                  break label301;
               }

               if (var63) {
                  try {
                     var73 = (new StringBuilder()).append("jointer.signFinalNative");
                     var71 = new String[6];
                  } catch (JSONException var46) {
                     var10000 = var46;
                     var10001 = false;
                     break label301;
                  }

                  var10002 = var71;
                  String[] var11;
                  var10003 = var11 = var71;

                  byte[] var10004;
                  String[] var10005;
                  long var10007;
                  try {
                     var10004 = var9;
                     var10005 = var11;
                     var10006 = var11;
                     var10007 = var59;
                     var11[0] = userName;
                     var11[1] = null;
                  } catch (JSONException var45) {
                     var10000 = var45;
                     var10001 = false;
                     break label301;
                  }

                  byte var60 = 2;

                  try {
                     var10006[var60] = String.valueOf(var10007);
                     var10005[3] = PIN;
                  } catch (JSONException var44) {
                     var10000 = var44;
                     var10001 = false;
                     break label301;
                  }

                  var60 = 4;

                  try {
                     var10003[var60] = Base64.encodeToString(var10004, 2);
                     var10002[5] = var10;
                     XLog.d(var73.append(Arrays.toString(var71)).toString());
                  } catch (JSONException var43) {
                     var10000 = var43;
                     var10001 = false;
                     break label301;
                  }
               }
            }
         }

         try {
            var62 = jointer.signFinalNative(userName, (String)null, var59, PIN, var9, var10, true);
         } catch (JSONException var42) {
            var10000 = var42;
            var10001 = false;
            break label301;
         }

         var10 = var62;

         try {
            var63 = IMSSdk.enableDebugLog;
         } catch (JSONException var41) {
            var10000 = var41;
            var10001 = false;
            break label301;
         }

         if (var63) {
            try {
               XLog.d("jointer.signFinalNative finalSign = " + var10);
            } catch (JSONException var40) {
               var10000 = var40;
               var10001 = false;
               break label301;
            }
         }

         try {
            var63 = this.isInfosecCollaborative();
         } catch (JSONException var39) {
            var10000 = var39;
            var10001 = false;
            break label301;
         }

         if (var63 && 0L != var59) {
            try {
               jointer.deleteHomoKeyNative(var59);
            } catch (JSONException var38) {
               var10000 = var38;
               var10001 = false;
               break label301;
            }
         }

         try {
            var63 = TextUtils.isEmpty(var10);
         } catch (JSONException var37) {
            var10000 = var37;
            var10001 = false;
            break label301;
         }

         Result var57;
         String[] var72;
         byte[] var75;
         if (var63) {
            Level var77;
            Logger var79;
            try {
               var79 = IMSSdk.mLogger;
               var77 = Level.SEVERE;
            } catch (JSONException var36) {
               var10000 = var36;
               var10001 = false;
               break label301;
            }

            String var66 = "协同签名失败:合成签名失败";

            try {
               var10003 = new String[6];
            } catch (JSONException var35) {
               var10000 = var35;
               var10001 = false;
               break label301;
            }

            String[] var54;
            var72 = var54 = var10003;

            String[] var10008;
            byte[] var10009;
            String[] var10010;
            long var10011;
            int var74;
            byte[] var76;
            try {
               var74 = type;
               var10006 = var54;
               var76 = plain;
               var10008 = var54;
               var10009 = var9;
               var10010 = var54;
               var10011 = var59;
               var54[0] = userName;
               var54[1] = PIN;
            } catch (JSONException var34) {
               var10000 = var34;
               var10001 = false;
               break label301;
            }

            byte var55 = 2;

            try {
               var10010[var55] = String.valueOf(var10011);
            } catch (JSONException var33) {
               var10000 = var33;
               var10001 = false;
               break label301;
            }

            var55 = 3;

            try {
               var10008[var55] = Base64.encodeToString(var10009, 2);
            } catch (JSONException var32) {
               var10000 = var32;
               var10001 = false;
               break label301;
            }

            var55 = 4;

            try {
               var10006[var55] = Base64.encodeToString(var76, 2);
            } catch (JSONException var31) {
               var10000 = var31;
               var10001 = false;
               break label301;
            }

            var55 = 5;

            try {
               var72[var55] = String.valueOf(var74);
               var79.log(var77, var66, var10003);
               var73 = (new StringBuilder()).append("协同签名失败:合成签名失败");
               var71 = new String[6];
            } catch (JSONException var30) {
               var10000 = var30;
               var10001 = false;
               break label301;
            }

            var10002 = var54 = var71;

            int var70;
            long var78;
            try {
               var70 = type;
               var72 = var54;
               var75 = plain;
               var10006 = var54;
               var76 = var9;
               var10008 = var54;
               var78 = var59;
               var54[0] = userName;
               var54[1] = PIN;
            } catch (JSONException var29) {
               var10000 = var29;
               var10001 = false;
               break label301;
            }

            var55 = 2;

            try {
               var10008[var55] = String.valueOf(var78);
            } catch (JSONException var28) {
               var10000 = var28;
               var10001 = false;
               break label301;
            }

            var55 = 3;

            try {
               var10006[var55] = Base64.encodeToString(var76, 2);
            } catch (JSONException var27) {
               var10000 = var27;
               var10001 = false;
               break label301;
            }

            var55 = 4;

            try {
               var72[var55] = Base64.encodeToString(var75, 2);
            } catch (JSONException var26) {
               var10000 = var26;
               var10001 = false;
               break label301;
            }

            var55 = 5;

            try {
               var10002[var55] = String.valueOf(var70);
               XLog.d(var73.append(Arrays.toString(var71)).toString());
               var61 = new Result;
            } catch (JSONException var25) {
               var10000 = var25;
               var10001 = false;
               break label301;
            }

            var57 = var61;

            try {
               var61.<init>("IE1007", "协同签名失败");
            } catch (JSONException var24) {
               var10000 = var24;
               var10001 = false;
               break label301;
            }
         } else {
            IMSCertAction var81;
            try {
               var81 = new IMSCertAction;
            } catch (JSONException var23) {
               var10000 = var23;
               var10001 = false;
               break label301;
            }

            IMSCertAction var80 = var81;

            try {
               var80.<init>(super.context);
               var62 = var81.getCertString(userName);
            } catch (JSONException var22) {
               var10000 = var22;
               var10001 = false;
               break label301;
            }

            userName = var62;

            try {
               var63 = IMSSdk.enableDebugLog;
            } catch (JSONException var21) {
               var10000 = var21;
               var10001 = false;
               break label301;
            }

            if (var63) {
               try {
                  XLog.d("签名type = " + type);
                  var73 = (new StringBuilder()).append("参数 ");
                  var71 = new String[3];
               } catch (JSONException var20) {
                  var10000 = var20;
                  var10001 = false;
                  break label301;
               }

               var10002 = var71;
               var10003 = var71;
               var72 = var71;
               var75 = plain;
               byte PIN1 = 0;

               try {
                  var72[PIN1] = Base64.encodeToString(var75, 2);
                  var10003[1] = userName;
                  var10002[2] = var10;
                  XLog.d(var73.append(Arrays.toString(var71)).toString());
               } catch (JSONException var19) {
                  var10000 = var19;
                  var10001 = false;
                  break label301;
               }
            }

            label234: {
               if (type != 1) {
                  if (type != 2) {
                     break label234;
                  }

                  try {
                     var62 = this.infosecSign.makeDetachedSignNative(userName, var10, (String)null);
                  } catch (JSONException var18) {
                     var10000 = var18;
                     var10001 = false;
                     break label301;
                  }
               } else {
                  try {
                     var62 = this.infosecSign.makeAttachedSignNative(plain, userName, var10, (String)null);
                  } catch (JSONException var17) {
                     var10000 = var17;
                     var10001 = false;
                     break label301;
                  }
               }

               var10 = var62;
            }

            try {
               var61 = new Result;
            } catch (JSONException var16) {
               var10000 = var16;
               var10001 = false;
               break label301;
            }

            var57 = var61;

            try {
               var61.<init>("000000", var10);
            } catch (JSONException var15) {
               var10000 = var15;
               var10001 = false;
               break label301;
            }
         }

         try {
            var63 = IMSSdk.enableDebugLog;
         } catch (JSONException var14) {
            var10000 = var14;
            var10001 = false;
            break label301;
         }

         if (var63) {
            try {
               XLog.d("签名结果 " + var10);
            } catch (JSONException var13) {
               var10000 = var13;
               var10001 = false;
               break label301;
            }
         }

         try {
            XLog.d("协同签名成功");
            return var57;
         } catch (JSONException var12) {
            var10000 = var12;
            var10001 = false;
         }
      }

      JSONException var58 = var10000;
      IMSSdk.mLogger.log(Level.SEVERE, "协同签名失败:JSON异常", var58);
      XLog.d("协同签名失败:JSON异常" + var58);
      return new Result("IE1008", responseData.toString());
   }

   public Map<String, String> collaborateSignFrontAuthBegin(@NonNull String userName, @NonNull String PIN, byte[] plain, @NonNull long otpTime, @NonNull String otpChallenge, boolean isHashSign, @NonNull Jointer jointer) {
      String var13;
      if (!TextUtils.isEmpty(userName) && plain != null) {
         long var9 = 0L;
         if (this.isInfosecCollaborative()) {
            var9 = jointer.createHomoKeyNative(1024);
            if (IMSSdk.enableDebugLog) {
               XLog.d("jointer.createHomoKeyNative " + var9);
            }
         }

         jointer.writeCacheData("HOMO_KEY_LABEL", var9);
         InfosecCert var11;
         var11 = new InfosecCert.<init>();
         if (IMSSdk.enableDebugLog) {
            XLog.d("infosecCert.getPublicKeyWithCertNative " + userName);
         }

         var13 = Base64.encodeToString(var11.getPublicKeyWithCertNative((new IMSCertAction(super.context)).getCertString(userName)), 2);
         if (IMSSdk.enableDebugLog) {
            XLog.d("infosecCert.getPublicKeyWithCertNative, publicKey = " + var13);
         }

         byte[][] var19;
         if (isHashSign) {
            if (IMSSdk.enableDebugLog) {
               XLog.d("jointer.signHashInitNative" + Arrays.toString(new String[]{String.valueOf(var9), Base64.encodeToString(plain, 2)}));
            }

            var19 = jointer.signHashInitNative(var9, plain);
         } else {
            if (IMSSdk.enableDebugLog) {
               XLog.d("jointer.signPlainInitNative" + Arrays.toString(new String[]{String.valueOf(var9), Base64.encodeToString(plain, 2), var13}));
            }

            var19 = jointer.signPlainInitNative(var9, plain, var13);
         }

         byte[] var14 = var19[0];
         plain = var19[1];
         if (IMSSdk.enableDebugLog) {
            XLog.d("jointer.signPlainInitNative, session = " + Base64.encodeToString(var14, 2));
            XLog.d("jointer.signPlainInitNative, signInitData = " + Base64.encodeToString(plain, 2));
         }

         jointer.writeCacheData("COLLABORATE_SESSION", var14);
         HashMap var15;
         HashMap var21 = var15 = new HashMap;
         var15.<init>();
         var15.put("username", userName);
         var21.put("initdata", Base64.encodeToString(plain, 2));
         int plain1;
         int var22 = plain1 = IMSSdk.getOTPLength();
         long var23 = otpTime;
         String otpTime1 = "password";
         InfosecOTP var5;
         var5 = new InfosecOTP.<init>();
         String isHashSign1 = "GUOMI";
         var9 = var23 / 1000L;
         if (var22 == 0) {
            plain1 = 6;
         }

         var15.put(otpTime1, var5.getOTP(userName, PIN, isHashSign1, var9, otpChallenge, plain1, 60));
         var15.put("challenge", otpChallenge);
         var15.put("imei", Util.getIdentifier(IMSSdk.mContext));
         return var15;
      } else {
         IMSSignAction var10000 = this;
         Logger var10001 = IMSSdk.mLogger;
         Level var10002 = Level.SEVERE;
         String[] var12;
         String[] var10003 = var12 = new String[2];
         var10003[0] = userName;
         PIN = new String.<init>(plain);
         var10003[1] = PIN;
         var10001.log(var10002, "协同签名失败:参数不合法", var12);
         StringBuilder var20 = (new StringBuilder()).append("协同签名失败:参数不合法");
         String[] var24 = new String[]{userName, null};
         var13 = new String.<init>(plain);
         var24[1] = var13;
         XLog.d(var20.append(Arrays.toString(var24)).toString());
         var10000.setLatestResult(new Result("IE1013"));
         return null;
      }
   }

   public Result collaborateSignFrontAuthFinal(@NonNull String userName, @NonNull String PIN, byte[] plain, int type, @NonNull long otpTime, @NonNull String otpChallenge, JSONObject responseData, @NonNull Jointer jointer) {
      JSONException var10000;
      label356: {
         boolean var10001;
         Result var78;
         try {
            var78 = this.checkResponseData(responseData);
         } catch (JSONException var63) {
            var10000 = var63;
            var10001 = false;
            break label356;
         }

         Result var10 = var78;
         String var79 = "000000";

         boolean var80;
         try {
            var80 = TextUtils.equals(var79, var10.getResultID());
         } catch (JSONException var62) {
            var10000 = var62;
            var10001 = false;
            break label356;
         }

         if (!var80) {
            return var10;
         }

         long var10002;
         JSONObject var81;
         Jointer var82;
         try {
            var81 = responseData;
            var82 = jointer;
            var10002 = (Long)jointer.readCacheData("HOMO_KEY_LABEL");
         } catch (JSONException var61) {
            var10000 = var61;
            var10001 = false;
            break label356;
         }

         long var75 = var10002;

         byte[] var84;
         try {
            var84 = (byte[])var82.readCacheData("COLLABORATE_SESSION");
         } catch (JSONException var60) {
            var10000 = var60;
            var10001 = false;
            break label356;
         }

         byte[] var12 = var84;

         try {
            var79 = var81.getString("data");
         } catch (JSONException var59) {
            var10000 = var59;
            var10001 = false;
            break label356;
         }

         String var13 = var79;

         try {
            var80 = IMSSdk.enableDebugLog;
         } catch (JSONException var58) {
            var10000 = var58;
            var10001 = false;
            break label356;
         }

         String[] var10003;
         String[] var10006;
         String[] var83;
         String[] var88;
         StringBuilder var89;
         if (var80) {
            try {
               var89 = (new StringBuilder()).append("jointer.signFinalNative");
               var88 = new String[6];
            } catch (JSONException var57) {
               var10000 = var57;
               var10001 = false;
               break label356;
            }

            var83 = var88;
            String[] var14;
            var10003 = var14 = var88;

            byte[] var10004;
            String[] var10005;
            long var10007;
            try {
               var10004 = var12;
               var10005 = var14;
               var10006 = var14;
               var10007 = var75;
               var14[0] = userName;
               var14[1] = null;
            } catch (JSONException var56) {
               var10000 = var56;
               var10001 = false;
               break label356;
            }

            byte var77 = 2;

            try {
               var10006[var77] = String.valueOf(var10007);
               var10005[3] = PIN;
            } catch (JSONException var55) {
               var10000 = var55;
               var10001 = false;
               break label356;
            }

            var77 = 4;

            try {
               var10003[var77] = Base64.encodeToString(var10004, 2);
               var83[5] = var13;
               XLog.d(var89.append(Arrays.toString(var88)).toString());
            } catch (JSONException var54) {
               var10000 = var54;
               var10001 = false;
               break label356;
            }
         }

         try {
            var79 = jointer.signFinalNative(userName, (String)null, var75, PIN, var12, var13, true);
         } catch (JSONException var53) {
            var10000 = var53;
            var10001 = false;
            break label356;
         }

         var13 = var79;

         try {
            var80 = IMSSdk.enableDebugLog;
         } catch (JSONException var52) {
            var10000 = var52;
            var10001 = false;
            break label356;
         }

         if (var80) {
            try {
               XLog.d("jointer.signFinalNative finalSign = " + var13);
            } catch (JSONException var51) {
               var10000 = var51;
               var10001 = false;
               break label356;
            }
         }

         try {
            var80 = this.isInfosecCollaborative();
         } catch (JSONException var50) {
            var10000 = var50;
            var10001 = false;
            break label356;
         }

         if (var80 && 0L != var75) {
            try {
               jointer.deleteHomoKeyNative(var75);
            } catch (JSONException var49) {
               var10000 = var49;
               var10001 = false;
               break label356;
            }
         }

         try {
            var80 = TextUtils.isEmpty(var13);
         } catch (JSONException var48) {
            var10000 = var48;
            var10001 = false;
            break label356;
         }

         Result userName1;
         String[] var90;
         byte[] var92;
         if (var80) {
            Level var94;
            Logger var95;
            try {
               var95 = IMSSdk.mLogger;
               var94 = Level.SEVERE;
            } catch (JSONException var47) {
               var10000 = var47;
               var10001 = false;
               break label356;
            }

            String var85 = "协同签名失败:合成签名失败";

            try {
               var10003 = new String[6];
            } catch (JSONException var46) {
               var10000 = var46;
               var10001 = false;
               break label356;
            }

            String[] var64;
            var90 = var64 = var10003;

            String[] var10008;
            byte[] var10009;
            String[] var10010;
            long var10011;
            int var91;
            byte[] var93;
            try {
               var91 = type;
               var10006 = var64;
               var93 = plain;
               var10008 = var64;
               var10009 = var12;
               var10010 = var64;
               var10011 = var75;
               var64[0] = userName;
               var64[1] = PIN;
            } catch (JSONException var45) {
               var10000 = var45;
               var10001 = false;
               break label356;
            }

            byte var65 = 2;

            try {
               var10010[var65] = String.valueOf(var10011);
            } catch (JSONException var44) {
               var10000 = var44;
               var10001 = false;
               break label356;
            }

            var65 = 3;

            try {
               var10008[var65] = Base64.encodeToString(var10009, 2);
            } catch (JSONException var43) {
               var10000 = var43;
               var10001 = false;
               break label356;
            }

            var65 = 4;

            try {
               var10006[var65] = Base64.encodeToString(var93, 2);
            } catch (JSONException var42) {
               var10000 = var42;
               var10001 = false;
               break label356;
            }

            var65 = 5;

            try {
               var90[var65] = String.valueOf(var91);
               var95.log(var94, var85, var10003);
               var89 = (new StringBuilder()).append("协同签名失败:合成签名失败");
               var88 = new String[6];
            } catch (JSONException var41) {
               var10000 = var41;
               var10001 = false;
               break label356;
            }

            var83 = var64 = var88;

            int var86;
            long var96;
            try {
               var86 = type;
               var90 = var64;
               var92 = plain;
               var10006 = var64;
               var93 = var12;
               var10008 = var64;
               var96 = var75;
               var64[0] = userName;
               var64[1] = PIN;
            } catch (JSONException var40) {
               var10000 = var40;
               var10001 = false;
               break label356;
            }

            var65 = 2;

            try {
               var10008[var65] = String.valueOf(var96);
            } catch (JSONException var39) {
               var10000 = var39;
               var10001 = false;
               break label356;
            }

            var65 = 3;

            try {
               var10006[var65] = Base64.encodeToString(var93, 2);
            } catch (JSONException var38) {
               var10000 = var38;
               var10001 = false;
               break label356;
            }

            var65 = 4;

            try {
               var90[var65] = Base64.encodeToString(var92, 2);
            } catch (JSONException var37) {
               var10000 = var37;
               var10001 = false;
               break label356;
            }

            var65 = 5;

            try {
               var83[var65] = String.valueOf(var86);
               XLog.d(var89.append(Arrays.toString(var88)).toString());
               var78 = new Result;
            } catch (JSONException var36) {
               var10000 = var36;
               var10001 = false;
               break label356;
            }

            Result var68 = var78;

            try {
               var78.<init>("IE1007", "协同签名失败");
            } catch (JSONException var35) {
               var10000 = var35;
               var10001 = false;
               break label356;
            }

            userName1 = var68;
         } else {
            IMSCertAction var98;
            try {
               var98 = new IMSCertAction;
            } catch (JSONException var34) {
               var10000 = var34;
               var10001 = false;
               break label356;
            }

            IMSCertAction var97 = var98;

            try {
               var97.<init>(super.context);
               var79 = var98.getCertString(userName);
            } catch (JSONException var33) {
               var10000 = var33;
               var10001 = false;
               break label356;
            }

            String jointer1 = var79;

            try {
               var80 = IMSSdk.enableDebugLog;
            } catch (JSONException var32) {
               var10000 = var32;
               var10001 = false;
               break label356;
            }

            if (var80) {
               try {
                  XLog.d("签名type = " + type);
                  var89 = (new StringBuilder()).append("参数 ");
                  var88 = new String[3];
               } catch (JSONException var31) {
                  var10000 = var31;
                  var10001 = false;
                  break label356;
               }

               var83 = var88;
               var10003 = var88;
               var90 = var88;
               var92 = plain;
               byte var76 = 0;

               try {
                  var90[var76] = Base64.encodeToString(var92, 2);
                  var10003[1] = jointer1;
                  var83[2] = var13;
                  XLog.d(var89.append(Arrays.toString(var88)).toString());
               } catch (JSONException var30) {
                  var10000 = var30;
                  var10001 = false;
                  break label356;
               }
            }

            label291: {
               if (type != 1) {
                  if (type != 2) {
                     break label291;
                  }

                  try {
                     var79 = this.infosecSign.makeDetachedSignNative(jointer1, var13, (String)null);
                  } catch (JSONException var29) {
                     var10000 = var29;
                     var10001 = false;
                     break label356;
                  }
               } else {
                  try {
                     var79 = this.infosecSign.makeAttachedSignNative(plain, jointer1, var13, (String)null);
                  } catch (JSONException var28) {
                     var10000 = var28;
                     var10001 = false;
                     break label356;
                  }
               }

               var13 = var79;
            }

            try {
               var81 = new JSONObject;
            } catch (JSONException var27) {
               var10000 = var27;
               var10001 = false;
               break label356;
            }

            JSONObject var69;
            JSONObject var99 = var69 = var81;

            try {
               var99.<init>();
               var81.put("signData", var13);
            } catch (JSONException var26) {
               var10000 = var26;
               var10001 = false;
               break label356;
            }

            int var100;
            try {
               var100 = IMSSdk.getSignAndTokenMode();
            } catch (JSONException var25) {
               var10000 = var25;
               var10001 = false;
               break label356;
            }

            if (3 == var100) {
               int var102;
               try {
                  var102 = IMSSdk.getOTPLength();
               } catch (JSONException var24) {
                  var10000 = var24;
                  var10001 = false;
                  break label356;
               }

               int plain1 = var102;
               long var101 = otpTime;
               String type1 = "otpCode";

               InfosecOTP var87;
               try {
                  var87 = new InfosecOTP;
               } catch (JSONException var23) {
                  var10000 = var23;
                  var10001 = false;
                  break label356;
               }

               InfosecOTP otpTime1 = var87;

               try {
                  var87.<init>();
               } catch (JSONException var22) {
                  var10000 = var22;
                  var10001 = false;
                  break label356;
               }

               String var6 = "GUOMI";

               try {
                  var101 /= 1000L;
               } catch (JSONException var21) {
                  var10000 = var21;
                  var10001 = false;
                  break label356;
               }

               var75 = var101;
               if (var102 == 0) {
                  plain1 = 6;
               }

               try {
                  var69.put(type1, otpTime1.getOTP(userName, PIN, var6, var75, otpChallenge, plain1, 60));
               } catch (JSONException var20) {
                  var10000 = var20;
                  var10001 = false;
                  break label356;
               }
            }

            try {
               var78 = new Result;
            } catch (JSONException var19) {
               var10000 = var19;
               var10001 = false;
               break label356;
            }

            userName1 = var78;
            var99 = var69;
            String var71 = "000000";

            try {
               var78.<init>(var71, var99.toString());
            } catch (JSONException var18) {
               var10000 = var18;
               var10001 = false;
               break label356;
            }
         }

         try {
            var80 = IMSSdk.enableDebugLog;
         } catch (JSONException var17) {
            var10000 = var17;
            var10001 = false;
            break label356;
         }

         if (var80) {
            try {
               XLog.d("签名结果 " + var13);
            } catch (JSONException var16) {
               var10000 = var16;
               var10001 = false;
               break label356;
            }
         }

         try {
            XLog.d("FrontAuth协同签名成功");
            return userName1;
         } catch (JSONException var15) {
            var10000 = var15;
            var10001 = false;
         }
      }

      JSONException var72 = var10000;
      IMSSdk.mLogger.log(Level.SEVERE, "FrontAuth协同签名失败:JSON异常", var72);
      XLog.d("FrontAuth协同签名失败:JSON异常" + var72);
      return new Result("IE1008", responseData.toString());
   }

   public Map<String, String> collaborateSignWithTokenBegin(@NonNull String userName, @NonNull String PIN, byte[] plain, @NonNull long otpTime, @NonNull String otpChallenge, boolean isHashSign, @NonNull Jointer jointer) {
      String var10;
      if (!TextUtils.isEmpty(userName) && plain != null) {
         otpTime = 0L;
         if (this.isInfosecCollaborative()) {
            otpTime = jointer.createHomoKeyNative(1024);
            if (IMSSdk.enableDebugLog) {
               XLog.d("jointer.createHomoKeyNative " + otpTime);
            }
         }

         jointer.writeCacheData("HOMO_KEY_LABEL", otpTime);
         InfosecCert PIN1;
         PIN1 = new InfosecCert.<init>();
         if (IMSSdk.enableDebugLog) {
            XLog.d("infosecCert.getPublicKeyWithCertNative " + userName);
         }

         var10 = Base64.encodeToString(PIN1.getPublicKeyWithCertNative((new IMSCertAction(super.context)).getCertString(userName)), 2);
         if (IMSSdk.enableDebugLog) {
            XLog.d("infosecCert.getPublicKeyWithCertNative, publicKey = " + var10);
         }

         byte[][] var14;
         if (isHashSign) {
            if (IMSSdk.enableDebugLog) {
               XLog.d("jointer.signHashInitNative" + Arrays.toString(new String[]{String.valueOf(otpTime), Base64.encodeToString(plain, 2)}));
            }

            var14 = jointer.signHashInitNative(otpTime, plain);
         } else {
            if (IMSSdk.enableDebugLog) {
               XLog.d("jointer.signPlainInitNative" + Arrays.toString(new String[]{String.valueOf(otpTime), Base64.encodeToString(plain, 2), var10}));
            }

            var14 = jointer.signPlainInitNative(otpTime, plain, var10);
         }

         byte[] var11 = var14[0];
         byte[] PIN2 = var14[1];
         if (IMSSdk.enableDebugLog) {
            XLog.d("jointer.signPlainInitNative, session = " + Base64.encodeToString(var11, 2));
            XLog.d("jointer.signPlainInitNative, signInitData = " + Base64.encodeToString(PIN2, 2));
         }

         jointer.writeCacheData("COLLABORATE_SESSION", var11);
         HashMap var16 = new HashMap();
         var16.put("username", userName);
         var16.put("initdata", Base64.encodeToString(PIN2, 2));
         var16.put("imei", Util.getIdentifier(IMSSdk.mContext));
         return var16;
      } else {
         IMSSignAction var10000 = this;
         Logger var10001 = IMSSdk.mLogger;
         Level var10002 = Level.SEVERE;
         String[] var9;
         String[] var10003 = var9 = new String[2];
         var10003[0] = userName;
         PIN = new String.<init>(plain);
         var10003[1] = PIN;
         var10001.log(var10002, "SignWithToken协同签名失败:参数不合法", var9);
         StringBuilder var15 = (new StringBuilder()).append("SignWithToken协同签名失败:参数不合法");
         String[] var17 = new String[]{userName, null};
         var10 = new String.<init>(plain);
         var17[1] = var10;
         XLog.d(var15.append(Arrays.toString(var17)).toString());
         var10000.setLatestResult(new Result("IE1013"));
         return null;
      }
   }

   public Result collaborateSignWithTokenFinal(@NonNull String userName, @NonNull String PIN, byte[] plain, int type, @NonNull long otpTime, @NonNull String otpChallenge, JSONObject responseData, @NonNull Jointer jointer) {
      JSONException var10000;
      label356: {
         boolean var10001;
         Result var78;
         try {
            var78 = this.checkResponseData(responseData);
         } catch (JSONException var63) {
            var10000 = var63;
            var10001 = false;
            break label356;
         }

         Result var10 = var78;
         String var79 = "000000";

         boolean var80;
         try {
            var80 = TextUtils.equals(var79, var10.getResultID());
         } catch (JSONException var62) {
            var10000 = var62;
            var10001 = false;
            break label356;
         }

         if (!var80) {
            return var10;
         }

         long var10002;
         JSONObject var81;
         Jointer var82;
         try {
            var81 = responseData;
            var82 = jointer;
            var10002 = (Long)jointer.readCacheData("HOMO_KEY_LABEL");
         } catch (JSONException var61) {
            var10000 = var61;
            var10001 = false;
            break label356;
         }

         long var75 = var10002;

         byte[] var84;
         try {
            var84 = (byte[])var82.readCacheData("COLLABORATE_SESSION");
         } catch (JSONException var60) {
            var10000 = var60;
            var10001 = false;
            break label356;
         }

         byte[] var12 = var84;

         try {
            var79 = var81.getString("data");
         } catch (JSONException var59) {
            var10000 = var59;
            var10001 = false;
            break label356;
         }

         String var13 = var79;

         try {
            var80 = IMSSdk.enableDebugLog;
         } catch (JSONException var58) {
            var10000 = var58;
            var10001 = false;
            break label356;
         }

         String[] var10003;
         String[] var10006;
         String[] var83;
         String[] var88;
         StringBuilder var89;
         if (var80) {
            try {
               var89 = (new StringBuilder()).append("jointer.signFinalNative");
               var88 = new String[6];
            } catch (JSONException var57) {
               var10000 = var57;
               var10001 = false;
               break label356;
            }

            var83 = var88;
            String[] var14;
            var10003 = var14 = var88;

            byte[] var10004;
            String[] var10005;
            long var10007;
            try {
               var10004 = var12;
               var10005 = var14;
               var10006 = var14;
               var10007 = var75;
               var14[0] = userName;
               var14[1] = null;
            } catch (JSONException var56) {
               var10000 = var56;
               var10001 = false;
               break label356;
            }

            byte var77 = 2;

            try {
               var10006[var77] = String.valueOf(var10007);
               var10005[3] = PIN;
            } catch (JSONException var55) {
               var10000 = var55;
               var10001 = false;
               break label356;
            }

            var77 = 4;

            try {
               var10003[var77] = Base64.encodeToString(var10004, 2);
               var83[5] = var13;
               XLog.d(var89.append(Arrays.toString(var88)).toString());
            } catch (JSONException var54) {
               var10000 = var54;
               var10001 = false;
               break label356;
            }
         }

         try {
            var79 = jointer.signFinalNative(userName, (String)null, var75, PIN, var12, var13, true);
         } catch (JSONException var53) {
            var10000 = var53;
            var10001 = false;
            break label356;
         }

         var13 = var79;

         try {
            var80 = IMSSdk.enableDebugLog;
         } catch (JSONException var52) {
            var10000 = var52;
            var10001 = false;
            break label356;
         }

         if (var80) {
            try {
               XLog.d("jointer.signFinalNative finalSign = " + var13);
            } catch (JSONException var51) {
               var10000 = var51;
               var10001 = false;
               break label356;
            }
         }

         try {
            var80 = this.isInfosecCollaborative();
         } catch (JSONException var50) {
            var10000 = var50;
            var10001 = false;
            break label356;
         }

         if (var80 && 0L != var75) {
            try {
               jointer.deleteHomoKeyNative(var75);
            } catch (JSONException var49) {
               var10000 = var49;
               var10001 = false;
               break label356;
            }
         }

         try {
            var80 = TextUtils.isEmpty(var13);
         } catch (JSONException var48) {
            var10000 = var48;
            var10001 = false;
            break label356;
         }

         Result userName1;
         String[] var90;
         byte[] var92;
         if (var80) {
            Level var94;
            Logger var95;
            try {
               var95 = IMSSdk.mLogger;
               var94 = Level.SEVERE;
            } catch (JSONException var47) {
               var10000 = var47;
               var10001 = false;
               break label356;
            }

            String var85 = "SignWithToken协同签名失败:合成签名失败";

            try {
               var10003 = new String[6];
            } catch (JSONException var46) {
               var10000 = var46;
               var10001 = false;
               break label356;
            }

            String[] var64;
            var90 = var64 = var10003;

            String[] var10008;
            byte[] var10009;
            String[] var10010;
            long var10011;
            int var91;
            byte[] var93;
            try {
               var91 = type;
               var10006 = var64;
               var93 = plain;
               var10008 = var64;
               var10009 = var12;
               var10010 = var64;
               var10011 = var75;
               var64[0] = userName;
               var64[1] = PIN;
            } catch (JSONException var45) {
               var10000 = var45;
               var10001 = false;
               break label356;
            }

            byte var65 = 2;

            try {
               var10010[var65] = String.valueOf(var10011);
            } catch (JSONException var44) {
               var10000 = var44;
               var10001 = false;
               break label356;
            }

            var65 = 3;

            try {
               var10008[var65] = Base64.encodeToString(var10009, 2);
            } catch (JSONException var43) {
               var10000 = var43;
               var10001 = false;
               break label356;
            }

            var65 = 4;

            try {
               var10006[var65] = Base64.encodeToString(var93, 2);
            } catch (JSONException var42) {
               var10000 = var42;
               var10001 = false;
               break label356;
            }

            var65 = 5;

            try {
               var90[var65] = String.valueOf(var91);
               var95.log(var94, var85, var10003);
               var89 = (new StringBuilder()).append("SignWithToken协同签名失败:合成签名失败");
               var88 = new String[6];
            } catch (JSONException var41) {
               var10000 = var41;
               var10001 = false;
               break label356;
            }

            var83 = var64 = var88;

            int var86;
            long var96;
            try {
               var86 = type;
               var90 = var64;
               var92 = plain;
               var10006 = var64;
               var93 = var12;
               var10008 = var64;
               var96 = var75;
               var64[0] = userName;
               var64[1] = PIN;
            } catch (JSONException var40) {
               var10000 = var40;
               var10001 = false;
               break label356;
            }

            var65 = 2;

            try {
               var10008[var65] = String.valueOf(var96);
            } catch (JSONException var39) {
               var10000 = var39;
               var10001 = false;
               break label356;
            }

            var65 = 3;

            try {
               var10006[var65] = Base64.encodeToString(var93, 2);
            } catch (JSONException var38) {
               var10000 = var38;
               var10001 = false;
               break label356;
            }

            var65 = 4;

            try {
               var90[var65] = Base64.encodeToString(var92, 2);
            } catch (JSONException var37) {
               var10000 = var37;
               var10001 = false;
               break label356;
            }

            var65 = 5;

            try {
               var83[var65] = String.valueOf(var86);
               XLog.d(var89.append(Arrays.toString(var88)).toString());
               var78 = new Result;
            } catch (JSONException var36) {
               var10000 = var36;
               var10001 = false;
               break label356;
            }

            Result var68 = var78;

            try {
               var78.<init>("IE1007", "协同签名失败");
            } catch (JSONException var35) {
               var10000 = var35;
               var10001 = false;
               break label356;
            }

            userName1 = var68;
         } else {
            IMSCertAction var98;
            try {
               var98 = new IMSCertAction;
            } catch (JSONException var34) {
               var10000 = var34;
               var10001 = false;
               break label356;
            }

            IMSCertAction var97 = var98;

            try {
               var97.<init>(super.context);
               var79 = var98.getCertString(userName);
            } catch (JSONException var33) {
               var10000 = var33;
               var10001 = false;
               break label356;
            }

            String jointer1 = var79;

            try {
               var80 = IMSSdk.enableDebugLog;
            } catch (JSONException var32) {
               var10000 = var32;
               var10001 = false;
               break label356;
            }

            if (var80) {
               try {
                  XLog.d("签名type = " + type);
                  var89 = (new StringBuilder()).append("参数 ");
                  var88 = new String[3];
               } catch (JSONException var31) {
                  var10000 = var31;
                  var10001 = false;
                  break label356;
               }

               var83 = var88;
               var10003 = var88;
               var90 = var88;
               var92 = plain;
               byte var76 = 0;

               try {
                  var90[var76] = Base64.encodeToString(var92, 2);
                  var10003[1] = jointer1;
                  var83[2] = var13;
                  XLog.d(var89.append(Arrays.toString(var88)).toString());
               } catch (JSONException var30) {
                  var10000 = var30;
                  var10001 = false;
                  break label356;
               }
            }

            label291: {
               if (type != 1) {
                  if (type != 2) {
                     break label291;
                  }

                  try {
                     var79 = this.infosecSign.makeDetachedSignNative(jointer1, var13, (String)null);
                  } catch (JSONException var29) {
                     var10000 = var29;
                     var10001 = false;
                     break label356;
                  }
               } else {
                  try {
                     var79 = this.infosecSign.makeAttachedSignNative(plain, jointer1, var13, (String)null);
                  } catch (JSONException var28) {
                     var10000 = var28;
                     var10001 = false;
                     break label356;
                  }
               }

               var13 = var79;
            }

            try {
               var81 = new JSONObject;
            } catch (JSONException var27) {
               var10000 = var27;
               var10001 = false;
               break label356;
            }

            JSONObject var69;
            JSONObject var99 = var69 = var81;

            try {
               var99.<init>();
               var81.put("signData", var13);
            } catch (JSONException var26) {
               var10000 = var26;
               var10001 = false;
               break label356;
            }

            int var100;
            try {
               var100 = IMSSdk.getSignAndTokenMode();
            } catch (JSONException var25) {
               var10000 = var25;
               var10001 = false;
               break label356;
            }

            if (1 == var100) {
               int var102;
               try {
                  var102 = IMSSdk.getOTPLength();
               } catch (JSONException var24) {
                  var10000 = var24;
                  var10001 = false;
                  break label356;
               }

               int plain1 = var102;
               long var101 = otpTime;
               String type1 = "otpCode";

               InfosecOTP var87;
               try {
                  var87 = new InfosecOTP;
               } catch (JSONException var23) {
                  var10000 = var23;
                  var10001 = false;
                  break label356;
               }

               InfosecOTP otpTime1 = var87;

               try {
                  var87.<init>();
               } catch (JSONException var22) {
                  var10000 = var22;
                  var10001 = false;
                  break label356;
               }

               String var6 = "GUOMI";

               try {
                  var101 /= 1000L;
               } catch (JSONException var21) {
                  var10000 = var21;
                  var10001 = false;
                  break label356;
               }

               var75 = var101;
               if (var102 == 0) {
                  plain1 = 6;
               }

               try {
                  var69.put(type1, otpTime1.getOTP(userName, PIN, var6, var75, otpChallenge, plain1, 60));
               } catch (JSONException var20) {
                  var10000 = var20;
                  var10001 = false;
                  break label356;
               }
            }

            try {
               var78 = new Result;
            } catch (JSONException var19) {
               var10000 = var19;
               var10001 = false;
               break label356;
            }

            userName1 = var78;
            var99 = var69;
            String var71 = "000000";

            try {
               var78.<init>(var71, var99.toString());
            } catch (JSONException var18) {
               var10000 = var18;
               var10001 = false;
               break label356;
            }
         }

         try {
            var80 = IMSSdk.enableDebugLog;
         } catch (JSONException var17) {
            var10000 = var17;
            var10001 = false;
            break label356;
         }

         if (var80) {
            try {
               XLog.d("签名结果 " + var13);
            } catch (JSONException var16) {
               var10000 = var16;
               var10001 = false;
               break label356;
            }
         }

         try {
            XLog.d("SignWithToken协同签名成功");
            return userName1;
         } catch (JSONException var15) {
            var10000 = var15;
            var10001 = false;
         }
      }

      JSONException var72 = var10000;
      IMSSdk.mLogger.log(Level.SEVERE, "SignWithToken协同签名失败:JSON异常", var72);
      XLog.d("SignWithToken协同签名失败:JSON异常" + var72);
      return new Result("IE1008", responseData.toString());
   }

   public String sign(@NonNull String userName, @NonNull String PIN, byte[] plain, int type) {
      if (IMSSdk.enableDebugLog) {
         XLog.d("signNative " + Arrays.toString(new String[]{Base64.encodeToString(plain, 2), userName, PIN}));
      }

      PIN = this.infosecSign.signNative(plain, userName, PIN, (String)null);
      if (IMSSdk.enableDebugLog) {
         XLog.d("signNative signResult " + PIN);
      }

      userName = (new IMSCertAction(super.context)).getCertString(userName);
      if (type != 1) {
         if (type == 2) {
            PIN = this.infosecSign.makeDetachedSignNative(userName, PIN, (String)null);
         }
      } else {
         PIN = this.infosecSign.makeAttachedSignNative(plain, userName, PIN, (String)null);
      }

      if (IMSSdk.enableDebugLog) {
         XLog.d("签名type = " + type);
         XLog.d("签名结果 " + PIN);
      }

      XLog.d("签名成功");
      return PIN;
   }

   public String signHash(@NonNull String userName, @NonNull String PIN, byte[] plain, int type, String hashAlg) {
      if (IMSSdk.enableDebugLog) {
         XLog.d("signHashNative " + Arrays.toString(new String[]{Base64.encodeToString(plain, 2), userName, PIN, hashAlg}));
      }

      PIN = this.infosecSign.signHashNative(plain, userName, PIN, hashAlg);
      userName = (new IMSCertAction(super.context)).getCertString(userName);
      if (type != 1) {
         if (type == 2) {
            PIN = this.infosecSign.makeDetachedSignNative(userName, PIN, (String)null);
         }
      } else {
         PIN = this.infosecSign.makeAttachedSignNative(plain, userName, PIN, (String)null);
      }

      if (IMSSdk.enableDebugLog) {
         XLog.d("签名type = " + type);
         XLog.d("签名结果 " + PIN);
      }

      if (TextUtils.isEmpty(PIN)) {
         XLog.d("签名失败");
      } else {
         XLog.d("签名成功");
      }

      return PIN;
   }

   public Map<String, String> rawVerifyBegin(@NonNull String signData, @NonNull String plainText, @NonNull String base64Cert) {
      if (!TextUtils.isEmpty(signData) && !TextUtils.isEmpty(plainText) && !TextUtils.isEmpty(base64Cert)) {
         HashMap var5 = new HashMap();
         var5.put("plaintext", plainText);
         var5.put("signedtext", signData);
         var5.put("tsatext", "EMP");
         var5.put("cert", base64Cert);
         return var5;
      } else {
         IMSSignAction var10000 = this;
         Logger var10001 = IMSSdk.mLogger;
         Level var10002 = Level.SEVERE;
         String[] var4;
         String[] var10003 = var4 = new String[3];
         var10003[0] = signData;
         var10003[1] = plainText;
         var10003[2] = base64Cert;
         var10001.log(var10002, "raw验签失败:参数不合法", var4);
         XLog.d("raw验签失败:参数不合法" + Arrays.toString(new String[]{signData, plainText, base64Cert}));
         var10000.setLatestResult(new Result("IE1013"));
         return null;
      }
   }

   public Map<String, String> detachVerifyBegin(@NonNull String signData, @NonNull String plainText) {
      if (!TextUtils.isEmpty(signData) && !TextUtils.isEmpty(plainText)) {
         HashMap var4 = new HashMap();
         var4.put("plaintext", plainText);
         var4.put("signedtext", signData);
         var4.put("tsatext", "EMP");
         return var4;
      } else {
         IMSSignAction var10000 = this;
         Logger var10001 = IMSSdk.mLogger;
         Level var10002 = Level.SEVERE;
         String[] var3;
         String[] var10003 = var3 = new String[2];
         var10003[0] = signData;
         var10003[1] = plainText;
         var10001.log(var10002, "detach验签失败:参数不合法", var3);
         XLog.d("detach验签失败:参数不合法" + Arrays.toString(new String[]{signData, plainText}));
         var10000.setLatestResult(new Result("IE1013"));
         return null;
      }
   }

   public Map<String, String> attachVerifyBegin(@NonNull String signData) {
      if (TextUtils.isEmpty(signData)) {
         IMSSignAction var2 = this;
         Logger var10001 = IMSSdk.mLogger;
         Level var10002 = Level.SEVERE;
         String[] var3;
         (var3 = new String[1])[0] = signData;
         var10001.log(var10002, "attach验签失败:参数不合法", var3);
         XLog.d("attach验签失败:参数不合法" + Arrays.toString(new String[]{signData}));
         var2.setLatestResult(new Result("IE1013"));
         return null;
      } else {
         HashMap var10000 = new HashMap();
         var10000.put("signedtext", signData);
         var10000.put("tsatext", "EMP");
         return var10000;
      }
   }

   public Map<String, String> verifyWithTokenBegin(@NonNull String signMode, @NonNull String signData, @NonNull String plainText, @NonNull String base64Cert, @NonNull String otpCode, @NonNull String otpChallenge) {
      if (!TextUtils.isEmpty(signData) && !TextUtils.isEmpty(otpCode) && !TextUtils.isEmpty(otpChallenge)) {
         HashMap var8;
         var8 = new HashMap.<init>();
         if (!TextUtils.isEmpty(plainText)) {
            var8.put("plaintext", plainText);
         }

         var8.put("signedtext", signData);
         var8.put("tsatext", "EMP");
         if (!TextUtils.isEmpty(base64Cert)) {
            var8.put("cert", base64Cert);
         }

         var8.put("signMode", signMode);
         var8.put("needcert", "true");
         var8.put("flag", "0");
         var8.put("password", otpCode);
         var8.put("challenge", otpChallenge);
         return var8;
      } else {
         IMSSignAction var10000 = this;
         Logger var10001 = IMSSdk.mLogger;
         Level var10002 = Level.SEVERE;
         String[] var7;
         String[] var10003 = var7 = new String[3];
         var10003[0] = signData;
         var10003[1] = otpCode;
         var10003[2] = otpChallenge;
         var10001.log(var10002, "验签失败:参数不合法", var7);
         XLog.d("验签失败:参数不合法" + Arrays.toString(new String[]{signData}));
         var10000.setLatestResult(new Result("IE1013"));
         return null;
      }
   }

   public Result verifyFinal(JSONObject responseData) {
      return this.commonFinal(responseData);
   }

   public boolean rawVerifyLocal(@NonNull String signData, @NonNull byte[] plain, @NonNull String base64Cert) {
      String var4 = this.infosecCert.getCertInfo(base64Cert, 8);
      if (IMSSdk.enableDebugLog) {
         XLog.d("rawVerifyNative " + Arrays.toString(new String[]{signData, Base64.encodeToString(plain, 2), base64Cert}));
      }

      boolean var5 = this.infosecSign.rawVerifyNative(plain, base64Cert, signData, var4);
      if (IMSSdk.enableDebugLog) {
         XLog.d("rawVerifyNative " + var5);
      }

      return var5;
   }

   public boolean detachVerifyLocal(@NonNull String signData, @NonNull byte[] plain) {
      if (IMSSdk.enableDebugLog) {
         XLog.d("detachedVerifyNative " + Arrays.toString(new String[]{Base64.encodeToString(plain, 2), signData}));
      }

      String var3 = this.infosecSign.detachedVerifyNative(plain, signData);
      if (IMSSdk.enableDebugLog) {
         XLog.d("detachedVerifyNative " + var3);
      }

      return TextUtils.isEmpty(var3) ^ true;
   }

   public boolean attachVerifyLocal(@NonNull String signData) {
      if (IMSSdk.enableDebugLog) {
         XLog.d("attachedVerifyNative " + signData);
      }

      String var2 = this.infosecSign.attachedVerifyNative(signData);
      if (IMSSdk.enableDebugLog) {
         XLog.d("attachedVerifyNative " + var2);
      }

      return TextUtils.isEmpty(var2) ^ true;
   }
}
